==> kg_detective-0.1.0-py3-none-any.whl: kg_detective/en/kg_translation.py <==
kg_en_cn = {
  'noun_proper': '专有名词',
  'noun_countability': '名词可数性',
  'noun_with_indefinite_art': '不定冠词a/an+可数名词',
  'noun_with_definite_art': '定冠词the+名词',
  'noun_possessive': '名词所有格',
  'adj_ending_in_ed': '以ed结尾的形容词',
  'adj_ending_in_ing': '以ing结尾的形容词',
  'adj_order': '形容词的词序',
  'adj_for_equal_comparisons': '形容词的同级比较',
  'adj_comparative': '形容词的比较级',
  'adj_superlative': '形容词的最高级',
  'adv_of_frequency': '频度副词',
  'adv_of_manner': '方式副词',
  'adv_of_time': '时间副词',
  'adv_of_place': '地点副词',
  'adv_of_degree': '程度副词',
  'adv_for_equal_comparisons': '副词的同级比较',
  'adv_comparative': '副词的比较级',
  'adv_superlative': '副词的最高级',
  'prep_of_time': '时间介词',
  'prep_of_movement': '方位介词',
  'prep_of_manner': '方式介词',
  'prep_with_verb': '介词和动词搭配',
  'prep_with_adj': '介词和形容词搭配',
  'prep_with_noun': '介词和名词搭配',
  'verb_passive_voice': '被动语态',
  'verb_simple_present_tense': '一般现在时',
  'verb_simple_past_tense': '一般过去时',
  'verb_simple_future_tense': '一般将来时',
  'verb_present_progressive_tense': '现在进行时',
  'verb_past_progressive_tense': '过去进行时',
  'verb_present_perfect_tense': '现在完成时',
  'verb_past_perfect_tense': '过去完成时',
  'verb_copular': '系动词',
  'verb_non_finite': '非谓语动词',
  'verb_modal': '情态动词',
  'verb_auxiliary': '助动词',
  'verb_transitive': '及物动词',
  'verb_intransitive': '不及物动词',
  'pron_personal': '人称代词',
  'pron_possessive': '物主代词',
  'pron_reflexive': '反身代词',
  'pron_demonstrative': '指示代词',
  'pron_indefinite': '不定代词',
  'pron_relative': '关系代词',
  'pron_interrogative': '疑问代词',
  'det_cardinal_num': '基数词',
  'det_ordinal_num': '序数词',
  'det_indefinite_art': '不定冠词(a/an)',
  'det_definite_art': '定冠词(the)',
  'conj_subordinating': '从属连词',
  'conj_coordinating': '并列连词',
  'interj_interj': '感叹词',
  'simple_s_p': 'simple_s_p', 'simple_s_c_p': 'simple_s_c_p', 'simple_s_p_o': 'simple_s_p_o', 'simple_s_p_io_o': 'simple_s_p_io_o', 'simple_s_p_o_c': 'simple_s_p_o_c', 'compound_sen': 'compound_sen', 'nominal_subject_clause': 'nominal_subject_clause', 'nominal_object_clause': 'nominal_object_clause', 'nominal_predicative_clause': 'nominal_predicative_clause', 'nominal_appositive_clause': 'nominal_appositive_clause', 'relative_restrictive_clause': 'relative_restrictive_clause', 'relative_non_restrictive_clause': 'relative_non_restrictive_clause', 'adverbial_clause_of_time': 'adverbial_clause_of_time', 'adverbial_clause_of_reason': 'adverbial_clause_of_reason', 'adverbial_clause_of_comparison': 'adverbial_clause_of_comparison', 'adverbial_clause_of_condition': 'adverbial_clause_of_condition', 'adverbial_clause_of_concession': 'adverbial_clause_of_concession', 'adverbial_clause_of_purpose': 'adverbial_clause_of_purpose', 'adverbial_clause_of_result': 'adverbial_clause_of_result', 'subjunctive_present': 'subjunctive_present', 'subjunctive_past': 'subjunctive_past', 'subjunctive_future': 'subjunctive_future', 'subjunctive_inversion_in_mood': 'subjunctive_inversion_in_mood'}

==> kg_detective-0.1.26-py3-none-any.whl: kg_detective/en/kg_translation.py <==
kg_en_cn = {
  'noun_proper': '专有名词',
  'noun_countability': '名词可数性',
  'noun_with_indefinite_art': '不定冠词a/an+可数名词',
  'noun_with_definite_art': '定冠词the+名词',
  'noun_possessive': '名词所有格',
  'adj_ending_in_ed': '以ed结尾的形容词',
  'adj_ending_in_ing': '以ing结尾的形容词',
  'adj_order': '形容词的词序',
  'adj_for_equal_comparisons': '形容词的同级比较',
  'adj_comparative': '形容词的比较级',
  'adj_superlative': '形容词的最高级',
  'adv_of_frequency': '频度副词',
  'adv_of_manner': '方式副词',
  'adv_of_time': '时间副词',
  'adv_of_place': '地点副词',
  'adv_of_degree': '程度副词',
  'adv_for_equal_comparisons': '副词的同级比较',
  'adv_comparative': '副词的比较级',
  'adv_superlative': '副词的最高级',
  'prep_of_time': '时间介词',
  'prep_of_movement': '方位介词',
  'prep_of_manner': '方式介词',
  'prep_with_verb': '介词和动词搭配',
  'prep_with_adj': '介词和形容词搭配',
  'prep_with_noun': '介词和名词搭配',
  'verb_passive_voice': '被动语态',
  'verb_simple_present_tense': '一般现在时',
  'verb_simple_past_tense': '一般过去时',
  'verb_simple_future_tense': '一般将来时',
  'verb_present_progressive_tense': '现在进行时',
  'verb_past_progressive_tense': '过去进行时',
  'verb_present_perfect_tense': '现在完成时',
  'verb_past_perfect_tense': '过去完成时',
  'verb_copular': '系动词',
  'verb_non_finite': '非谓语动词',
  'verb_modal': '情态动词',
  'verb_auxiliary': '助动词',
  'verb_transitive': '及物动词',
  'verb_intransitive': '不及物动词',
  'pron_personal': '人称代词',
  'pron_possessive': '物主代词',
  'pron_reflexive': '反身代词',
  'pron_demonstrative': '指示代词',
  'pron_indefinite': '不定代词',
  'pron_relative': '关系代词',
  'pron_interrogative': '疑问代词',
  'det_cardinal_num': '基数词',
  'det_ordinal_num': '序数词',
  'det_indefinite_art': '不定冠词(a/an)',
  'det_definite_art': '定冠词(the)',
  'conj_subordinating': '从属连词',
  'conj_coordinating': '并列连词',
  'interj_interj': '感叹词',
  'nominal_subject_clause': '主语从句',
  'nominal_object_clause': '宾语从句',
  'nominal_predicative_clause': '表语从句',
  'relative_clause': '定语从句',
  'subjunctive_present': '现在虚拟',
  'subjunctive_past': '过去虚拟',
  'subjunctive_future': '将来虚拟',
}
